@@ -1,14 +1,18 @@
-use CairoX::Sweet::Standard;
+use 5.10.0;
 use strict;
 use warnings;
 
-# PODNAME: CairoX::Sweet::Role::PathCommand
+package CairoX::Sweet::Role::PathCommand;
 
-role CairoX::Sweet::Role::PathCommand using Moose {
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0200';
 
-    our $VERSION = '0.0108'; # VERSION
-    requires 'location', 'move_location';
-}
+use Moose::Role;
+
+requires qw/
+    location
+    move_location
+/;
 
 1;
 
@@ -24,7 +28,7 @@ CairoX::Sweet::Role::PathCommand
 
 =head1 VERSION
 
-Version 0.0108, released 2015-03-21.
+Version 0.0200, released 2016-08-22.
 
 =head1 SOURCE
 
@@ -40,7 +44,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
